@@ -10,9 +10,11 @@ use base 'CPANPLUS::Internals::Utils';
 use Config;
 use File::Spec;
 use Module::Load;
+use CPANPLUS;
 use CPANPLUS::Error;
 use CPANPLUS::Internals::Constants;
 
+use File::Basename              qw[dirname];
 use IPC::Cmd                    qw[can_run];
 use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 use Module::Load::Conditional   qw[check_install];
@@ -55,6 +57,7 @@ my $Conf = {
                                         __PACKAGE__->_home_dir, DOT_CPANPLUS ),
         'buildflags'                => '',
         'cpantest'                  => 0,
+        'cpantest_mx'               => '',
         'debug'                     => 0,
         'dist_type'                 => '',
         'email'                     => DEFAULT_EMAIL,
@@ -105,6 +108,34 @@ my $Conf = {
                               )
                             : can_run('sudo')
                         ),
+        ### perlwrapper that allows us to turn on autoflushing                        
+        'perlwrapper'   => (    ### parallel to your cpanp/cpanp-boxed
+                                do { my $f = File::Spec->rel2abs(
+                                        File::Spec->catdir( 
+                                            dirname($0), 'cpanp-run-perl' 
+                                        )
+                                     );
+                                    -e $f ? $f : undef
+                                } ||
+                                
+                                ### parallel to your CPANPLUS.pm:
+                                ### $INC{cpanplus}/../bin/cpanp-run-perl
+                                do { my $f = File::Spec->rel2abs(
+                                        File::Spec->catdir( 
+                                            dirname( $INC{'CPANPLUS.pm'} ),
+                                            '..',   # lib dir
+                                            'bin',  # bin dir
+                                            'cpanp-run-perl' 
+                                        )
+                                     );
+                                    -e $f ? $f : undef
+                                } ||
+                                
+                                ### in your path -- take this one last, the
+                                ### previous two assume extracted tarballs
+                                ### or user installs
+                                can_run('cpanp-run-perl'),
+                        ),         
     },
 
     ### _source, _build and _mirror are supposed to be static
@@ -157,6 +188,9 @@ sub new {
     
     $obj->_clean_up_paths;
     
+    ### shut up IPC::Cmd warning about not findin IPC::Run on win32
+    $IPC::Cmd::WARN = 0;
+    
     return $obj;
 }
 
