@@ -4,7 +4,7 @@ use strict;
 use vars    qw[@ISA $STATUS];
 @ISA =      qw[CPANPLUS::Dist];
 
-use CPANPLUS::inc;
+
 use CPANPLUS::Internals::Constants;
 use CPANPLUS::Internals::Constants::Report;
 use CPANPLUS::Error;
@@ -142,10 +142,12 @@ sub format_available {
         return;
     }
     
-    unless( $conf->get_program('make') ) { 
-        error( loc( "You do not have '%1' -- '%2' not available",
-                    'make', __PACKAGE__ ) ); 
-        return;
+    for my $pgm ( qw[make perlwrapper] ) {
+        unless( $conf->get_program( $pgm ) ) { 
+            error(loc("You do not have '%1'in your path -- '%2' not available",
+                        $pgm, __PACKAGE__ )); 
+            return;
+        }
     }
 
     return 1;     
@@ -200,9 +202,7 @@ sub prepare {
     my( $force, $verbose, $perl, $mmflags );
     {   local $Params::Check::ALLOW_UNKNOWN = 1;
         my $tmpl = {
-            perl            => {    default => 
-                                        $conf->get_program('perl') || $^X, 
-                                    store => \$perl },
+            perl            => {    default => $^X, store => \$perl },
             makemakerflags  => {    default =>
                                         $conf->get_conf('makemakerflags'),
                                     store => \$mmflags },                 
@@ -282,8 +282,26 @@ sub prepare {
             my $captured; my $makefile_pl = MAKEFILE_PL->();
             
             ### setting autoflush to true fixes issue from rt #8047
-            my $flush = OPT_AUTOFLUSH;
-            unless(scalar run(  command => "$perl $flush $makefile_pl $mmflags",
+            ### XXX this means that we need to keep the path to CPANPLUS
+            ### in @INC, stopping us from resolving dependencies on CPANPLUS
+            ### at bootstrap time properly.
+
+            ### XXX this fails under ipc::run due to the extra quotes,
+            ### but it works in ipc::open3. however, ipc::open3 doesn't work
+            ### on win32/cygwin. XXX TODO get a windows box and sort this out
+            # my $cmd =  qq[$perl -MEnglish -le ] . 
+            #            QUOTE_PERL_ONE_LINER->(
+            #                qq[\$OUTPUT_AUTOFLUSH++,do(q($makefile_pl))]
+            #            ) 
+            #            . $mmflags;
+
+            # my $flush = OPT_AUTOFLUSH;
+            # my $cmd     = "$perl $flush $makefile_pl $mmflags";
+
+            my $run_perl    = $conf->get_program('perlwrapper');
+            my $cmd         = "$perl $run_perl $makefile_pl $mmflags";
+
+            unless( scalar run( command => $cmd,
                                 buffer  => \$captured,
                                 verbose => $run_verbose, # may be interactive   
             ) ) {
@@ -298,6 +316,26 @@ sub prepare {
             msg( $captured, 0 );
         }
         
+        ### so, nasty feature in Module::Build, that when a Makefile.PL
+        ### is a disguised Build.PL, it generates a Build file, not a
+        ### Makefile. this breaks everything :( see rt bug #19741
+        if( not -e MAKEFILE->( $dir ) and -e BUILD_PL->( $dir ) ) {
+            error(loc(
+                    "We just ran '%1' without errors, but no '%2' is ".
+                    "present. However, there is a '%3' file, so this may ".
+                    "be related to bug #19741 in %4, which describes a ".
+                    "fake '%5' which generates a '%6' file instead of a '%7'. ".
+                    "You could try to work around this issue by setting '%8' ".
+                    "to false and trying again. This will attempt to use the ".
+                    "'%9' instead.",
+                    "$^X ".MAKEFILE_PL->(), MAKEFILE->(), BUILD_PL->(),
+                    'Module::Build', MAKEFILE_PL->(), 'Build', MAKEFILE->(),
+                    'prefer_makefile', BUILD_PL->()
+            ));           
+            
+            $fail++, last RUN;
+        }
+        
         ### if we got here, we managed to make a 'makefile' ###
         $dist->status->makefile( MAKEFILE->($dir) );               
         
@@ -435,9 +473,7 @@ sub create {
         $mmflags, $prereq_format, $prereq_build);
     {   local $Params::Check::ALLOW_UNKNOWN = 1;
         my $tmpl = {
-            perl            => {    default => 
-                                        $conf->get_program('perl') || $^X, 
-                                    store => \$perl },
+            perl            => {    default => $^X, store => \$perl },
             force           => {    default => $conf->get_conf('force'), 
                                     store   => \$force },
             verbose         => {    default => $conf->get_conf('verbose'), 
@@ -479,7 +515,7 @@ sub create {
         return;
     }
     
-    my $fail; my $prereq_fail; 
+    my $fail; my $prereq_fail; my $test_fail;
     RUN: {
         ### this will set the directory back to the start
         ### dir, so we must chdir /again/           
@@ -544,7 +580,8 @@ sub create {
             ### included in make test -- it should build without
             ### also, modules that run in taint mode break if we leave
             ### our code ref in perl5opt
-            local $ENV{PERL5OPT} = CPANPLUS::inc->original_perl5opt || '';
+            ### XXX CPANPLUS::inc functionality is now obsolete.
+            #local $ENV{PERL5OPT} = CPANPLUS::inc->original_perl5opt || '';
 
             ### you can turn off running this verbose by changing
             ### the config setting below, although it is really not 
@@ -556,7 +593,8 @@ sub create {
 
             ### XXX need to add makeflags here too? 
             ### yes, but they should really be split out -- see bug #4143
-            if(run( command => [$make, 'test', $makeflags],
+            if( scalar run( 
+                        command => [$make, 'test', $makeflags],
                         buffer  => \$captured,
                         verbose => $run_verbose,
             ) ) {
@@ -566,7 +604,7 @@ sub create {
                 if ( NO_TESTS_DEFINED->( $captured ) ) {
                     msg( NO_TESTS_DEFINED->( $captured ), 0 )
                 } else {
-                    msg( loc( "MAKE TEST passed: %2", $captured ) );
+                    msg( loc( "MAKE TEST passed: %2", $captured ), $verbose );
                 }
             
                 $dist->status->test(1);
@@ -577,6 +615,10 @@ sub create {
                 ### --higher level --kane.
                 $dist->status->test(0);
                
+                ### mark specifically *test* failure.. so we dont
+                ### send success on force...
+                $test_fail++;
+                
                 unless( $force ) {
                     $fail++; last RUN;     
                 }
@@ -593,7 +635,7 @@ sub create {
     if( $conf->get_conf('cpantest') and not $prereq_fail) {
         $cb->_send_report( 
             module  => $self,
-            failed  => $fail,
+            failed  => $test_fail || $fail,
             buffer  => CPANPLUS::Error->stack_as_string,
             verbose => $verbose,
             force   => $force,
@@ -616,6 +658,7 @@ Returns true on success, false on failure.
 =cut
 
 sub install {
+
     ### just in case you did the create with ANOTHER dist object linked
     ### to the same module object
     my $dist = shift();
