@@ -26,7 +26,7 @@ local $Data::Dumper::Indent     = 1; # for dumpering from !
 BEGIN {
     use vars        qw[ $VERSION @ISA ];
     @ISA        =   qw[ CPANPLUS::Shell::_Base::ReadLine ];
-    $VERSION = "0.074";
+    $VERSION = "0.076";
 }
 
 load CPANPLUS::Shell;
@@ -711,6 +711,7 @@ sub _shell {
         $cb->_chdir( dir => $mod->status->extract() )   or next;
 
         #local $ENV{PERL5OPT} = CPANPLUS::inc->original_perl5opt;
+
         if( system($shell) and $! ) {
             print loc("Error executing your subshell '%1': %2",
                         $shell, $!),"\n";
@@ -837,7 +838,7 @@ sub _install {
                 my $stack = CPANPLUS::Error->stack_as_string;
                 ### remove everything in the log that was there *before*
                 ### we started this install
-                substr( $stack, 0, $log_length );
+                substr( $stack, 0, $log_length, '' );
                 
                 print $fh $stack;
                 close $fh;
@@ -1117,6 +1118,11 @@ sub _set_conf {
 
         if ( $type eq 'program' or $type eq 'conf' ) {
 
+            my $format = {
+                conf    => '%-25s %s',
+                program => '%-12s %s',
+            }->{ $type };      
+
             unless( $key ) {
                 my @list =  grep { $_ ne 'hosts' }
                             $conf->options( type => $type );
@@ -1125,11 +1131,11 @@ sub _set_conf {
 
                 local $Data::Dumper::Indent = 0;
                 for my $name ( @list ) {
-                    my $val = $conf->$method($name);
+                    my $val = $conf->$method($name) || '';
                     ($val)  = ref($val)
                                 ? (Data::Dumper::Dumper($val) =~ /= (.*);$/)
                                 : "'$val'";
-                    printf  "    %-25s %s\n", $name, $val;
+                    printf  "    $format\n", $name, $val;
                 }
 
             } elsif ( $key eq 'hosts' ) {
